@@ -1,3 +1,5 @@
 mod protobuf_service;
+mod schema;
 
 pub use protobuf_service::*;
+pub use schema::*;
